From: normalperson@... Date: 2014-03-01T04:38:20+00:00 Subject: [ruby-core:61160] [ruby-trunk - Feature #9579] [PATCH] ext/extmk.rb: parallelize configure Issue #9579 has been updated by Eric Wong. Trivial addendum for v3 (pushed earlier, but I lost my Internet connection before I could email). http://bogomips.org/ruby.git/patch?id=5779e6040 git://80x24.org/ruby.git extmk-parallel-v3 ---------------------------------------- Feature #9579: [PATCH] ext/extmk.rb: parallelize configure https://bugs.ruby-lang.org/issues/9579#change-45526 * Author: Eric Wong * Status: Open * Priority: Normal * Assignee: Eric Wong * Category: build * Target version: current: 2.2.0 ---------------------------------------- This reduces "touch ext/extmk.rb && make -j" time from roughly 38 to 16 seconds on my 8 core machine with an otherwise fully-built source tree. http://bogomips.org/ruby.git/patch?id=bc6acbaa40 git pull git://80x24.org/ruby.git extmk-parallel -- http://bugs.ruby-lang.org/